==> haskell-xml-1.3.14-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml
version:              1.3.14
visibility:           public
id:                   xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
key:                  xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
license:              BSD-3-Clause
copyright:            (c) 2007-2008 Galois Inc.
maintainer:           diatchki@galois.com
author:               Galois Inc.
homepage:             http://code.galois.com
synopsis:             A simple XML library.
description:          A simple XML library.
category:             Text, XML
abi:                  876386c913e2ab7939a801f4553fd4d8
exposed:              True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types

import-dirs:          /usr/lib/ghc-8.8.3/site-local/xml-1.3.14
library-dirs:         /usr/lib/ghc-8.8.3/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/xml-1.3.14
hs-libraries:         HSxml-1.3.14-IT4S7IkihY28IGBFVjHe4u
depends:              base-4.13.0.0 bytestring-0.10.10.0 text-1.2.4.0
haddock-interfaces:   /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html:         /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-1.3.14-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml
version:              1.3.14
visibility:           public
id:                   xml-1.3.14-8hNGLq3d7aLH4jJmI1r9Bi
key:                  xml-1.3.14-8hNGLq3d7aLH4jJmI1r9Bi
license:              BSD-3-Clause
copyright:            (c) 2007-2008 Galois Inc.
maintainer:           diatchki@galois.com
author:               Galois Inc.
homepage:             http://code.galois.com
synopsis:             A simple XML library.
description:          A simple XML library.
category:             Text, XML
abi:                  8b0f9e330c311a6718efe96af4afbc7f
exposed:              True
exposed-modules:
    Text.XML.Light Text.XML.Light.Cursor Text.XML.Light.Input
    Text.XML.Light.Lexer Text.XML.Light.Output Text.XML.Light.Proc
    Text.XML.Light.Types

import-dirs:          /usr/lib/ghc-8.10.1/site-local/xml-1.3.14
library-dirs:         /usr/lib/ghc-8.10.1/site-local/xml-1.3.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/xml-1.3.14
hs-libraries:         HSxml-1.3.14-8hNGLq3d7aLH4jJmI1r9Bi
depends:              base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
haddock-interfaces:   /usr/share/doc/haskell-xml/html/xml.haddock
haddock-html:         /usr/share/doc/haskell-xml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
